Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1279)

Unified Diff: third_party/WebKit/Source/platform/graphics/gpu/DrawingBuffer.h

Issue 2810333009: Fix non-anti-aliased frame update. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | third_party/WebKit/Source/platform/graphics/gpu/DrawingBuffer.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/platform/graphics/gpu/DrawingBuffer.h
diff --git a/third_party/WebKit/Source/platform/graphics/gpu/DrawingBuffer.h b/third_party/WebKit/Source/platform/graphics/gpu/DrawingBuffer.h
index fe1c8b329f37be4a836d9fe9f884a0815fbfba40..dbf89a5ac459e1d50395be2218465b50ce037c72 100644
--- a/third_party/WebKit/Source/platform/graphics/gpu/DrawingBuffer.h
+++ b/third_party/WebKit/Source/platform/graphics/gpu/DrawingBuffer.h
@@ -168,7 +168,7 @@ class PLATFORM_EXPORT DrawingBuffer
}
// Returns false if the contents had previously been marked as changed and
// have not yet been committed.
bool markContentsChanged();
void setBufferClearNeeded(bool);
bool bufferClearNeeded() const;
@@ -342,9 +342,12 @@ class PLATFORM_EXPORT DrawingBuffer
// The same as reset(), but leaves GL state dirty.
bool resizeFramebufferInternal(const IntSize&);
- // The same as commit(), but leaves GL state dirty.
+ // The same as resolveAndBindForReadAndDraw(), but leaves GL state dirty.
void resolveMultisampleFramebufferInternal();
+ // Resolves m_multisampleFBO into m_fbo, if multisampling.
+ void resolveIfNeeded();
+
bool prepareTextureMailboxInternal(
cc::TextureMailbox* outMailbox,
std::unique_ptr<cc::SingleReleaseCallback>* outReleaseCallback,
@@ -481,9 +484,9 @@ class PLATFORM_EXPORT DrawingBuffer
// buffer.
bool m_contentsChanged = true;
- // True if commit() has been called since the last time markContentsChanged()
- // had been called.
- bool m_contentsChangeCommitted = false;
+ // True if resolveIfNeeded() has been called since the last time
+ // markContentsChanged() had been called.
+ bool m_contentsChangeResolved = false;
bool m_bufferClearNeeded = false;
// Whether the client wants a depth or stencil buffer.
« no previous file with comments | « no previous file | third_party/WebKit/Source/platform/graphics/gpu/DrawingBuffer.cpp » ('j') | no next file with comments »
@@ -168,7 +168,7 @@ class PLATFORM_EXPORT DrawingBuffer
}
// Returns false if the contents had previously been marked as changed and
- // have not yet been committed.
+ // have not yet been resolved.
bool markContentsChanged();
void setBufferClearNeeded(bool);

Powered by Google App Engine
This is Rietveld 408576698